#!/usr/bin/env python
# -*- coding: utf-8 -*-
from distutils.core import setup

setup(name='nbimporter',
      version='0.2',
      description='Import IPython notebooks as modules',
      author='Adam Schwartz',
      author_email='adam@anschwa.com',
      py_modules=['nbimporter', 'display_nb'],
      url='https://github.com/grst/nbimporter',
 )
